@@ -4,18 +4,20 @@ Files and directories
 """
 from __future__ import with_statement
 
-import os.path
+import os
 
 from fabric.api import *
 from fabric.contrib.files import upload_template as _upload_template
 from fabric.contrib.files import exists
 
+from fabtools.utils import run_as_root
+
 
 def is_file(path, use_sudo=False):
     """
     Check if a path exists, and is a file.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     with settings(hide('running', 'warnings'), warn_only=True):
         return func('[ -f "%(path)s" ]' % locals()).succeeded
 
@@ -24,7 +26,7 @@ def is_dir(path, use_sudo=False):
     """
     Check if a path exists, and is a directory.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     with settings(hide('running', 'warnings'), warn_only=True):
         return func('[ -d "%(path)s" ]' % locals()).succeeded
 
@@ -33,7 +35,7 @@ def is_link(path, use_sudo=False):
     """
     Check if a path exists, and is a symbolic link.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     with settings(hide('running', 'warnings'), warn_only=True):
         return func('[ -L "%(path)s" ]' % locals()).succeeded
 
@@ -42,7 +44,7 @@ def owner(path, use_sudo=False):
     """
     Get the owner name of a file or directory.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     # I'd prefer to use quiet=True, but that's not supported with older
     # versions of Fabric.
     with settings(hide('running', 'stdout'), warn_only=True):
@@ -58,7 +60,7 @@ def group(path, use_sudo=False):
     """
     Get the group name of a file or directory.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     # I'd prefer to use quiet=True, but that's not supported with older
     # versions of Fabric.
     with settings(hide('running', 'stdout'), warn_only=True):
@@ -77,7 +79,7 @@ def mode(path, use_sudo=False):
     Returns a string such as ``'0755'``, representing permissions as
     an octal number.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     # I'd prefer to use quiet=True, but that's not supported with older
     # versions of Fabric.
     with settings(hide('running', 'stdout'), warn_only=True):
@@ -103,14 +105,14 @@ def upload_template(filename, template, context=None, use_sudo=False,
     _upload_template(os.path.join("templates", template), filename,
                     context=context, use_sudo=use_sudo)
     if chown:
-        sudo('chown %s:%s "%s"' % (user, user, filename))
+        run_as_root('chown %s:%s "%s"' % (user, user, filename))
 
 
 def md5sum(filename, use_sudo=False):
     """
     Compute the MD5 sum of a file.
     """
-    func = use_sudo and sudo or run
+    func = use_sudo and run_as_root or run
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
         # Linux (LSB)
         if exists(u'/usr/bin/md5sum'):
