@@ -8,6 +8,8 @@ from pipes import quote
 
 from fabric.api import *
 
+from fabtools.utils import run_as_root
+
 
 def exists(name):
     """
@@ -35,4 +37,4 @@ def create(name, gid=None):
         args.append('-g %s' % quote(gid))
     args.append(name)
     args = ' '.join(args)
-    sudo('groupadd %s' % args)
+    run_as_root('groupadd %s' % args)
